
XEP-0482: Call Invites
======================

.. module:: slixmpp.plugins.xep_0482

.. autoclass:: XEP_0482
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0482.stanza
    :members:
    :undoc-members:

